
#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

in vec2 uv;

// which mipMap level should be used for texture lookups?
uniform int mipMapLevel;
uniform sampler2D texture;

// (1,0) for blur along x-axis and (0,1) for blur along y-axis
uniform vec2 direction;

out vec4 fragColor;

// gaussian blur kernel
int kernelSize = 3;
vec2 kernel[3];


void initKernel(){
	
	float overkill = 0;
	for(int i = 0; i < kernelSize; i=i+1){
		int offset = i - (kernelSize-1)/2;
		overkill  =  overkill + (pow(2f, (kernelSize-1)/2 - abs(offset)) / pow(2f, (kernelSize+1)/2f));
	}
	
	for(int i = 0; i < kernelSize; i=i+1){
		int offset = i - (kernelSize-1)/2;
		float multiplier = (pow(2f, (kernelSize-1)/2 - abs(offset)) / pow(2f, (kernelSize+1)/2f)) /overkill;
		kernel[i] = vec2(offset, multiplier);
	}
}

void main(){
	initKernel();
	
	vec2 texSize = 1.0f /  textureSize(texture, mipMapLevel);

	fragColor = vec4(0,0,0,1);
	vec4 blurCol = vec4(0,0,0,1);
	for(int i = 0; i < kernelSize; i=i+1){
		vec2 offset = vec2(texSize.x*kernel[i].x, texSize.x*kernel[i].x) * direction;
		vec4 texLodCol = textureLod(texture, uv + offset, mipMapLevel);
		//vec4 texLodCol = texture2D(texture, uv + offset);
		//texLodCol = texLodCol *texLodCol ;
		blurCol = blurCol + texLodCol * kernel[i].y;
	}
	
	vec4 texCol = texture2D(texture, uv);

	fragColor =  blurCol;
	fragColor.w = 1;	

}