//specular.frag

#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

// uniform shader-parameters
uniform int lightCount;	
uniform vec3 light_position[30];
uniform vec4 light_color[30];
uniform vec4 ambient_color;
uniform float opacity;
uniform float specularExponent;
uniform float specularCoefficient;
uniform bool useFragCoordMapping;
uniform vec2 windowSize;

uniform sampler2D texture;

// fragment-shader input variables
in vec4 frag_color;
in vec3 world_normal;
in vec4 world_position;
in vec2 texcoord;
in vec3 eye;
in vec4 objectSpacePos;

// fragment-shader output variable (-> stored in the frame-buffer, i.e. "the pixel you see")
out vec4 fragColor;


void main()
{
	// renormalize and homogenize input variables
	vec3 normal = normalize(world_normal);
    vec3 position = world_position.xyz / world_position.w;

	// calculate lighting
    vec4 ambient = ambient_color * frag_color;
    vec4 diffuse = vec4(0,0,0,0);
	vec4 specular = vec4(0,0,0,0);
	//frag_color * light_color * max(0.0, dot(normal, light_dir));
	int i = 0;
	for(i = 0; i <= lightCount; i++){
		// calculate the light-direction
		vec3 light_dir = normalize(light_position[i] - position);
		diffuse = diffuse + light_color[i] * max(0.0, dot(normal, light_dir));
		
		vec3 H = normalize(light_dir + eye);
		specular = specular + light_color[i] * max(0,pow(max(0.0, dot(normal, H)), specularExponent));
	}
	diffuse = frag_color * diffuse;
    
    // write color to output
    //fragColor = ambient + diffuse;
	
	vec4 texcol;
	if(useFragCoordMapping){
		vec2 uv = gl_FragCoord.xy;
		uv.x = uv.x / windowSize.x;
		uv.y = uv.y / windowSize.y;
		uv = uv * vec2(-1,1);
		texcol = textureLod(texture, uv, 0);
		//texcol = vec4(0,1,0,1);
	}else{
		texcol = texture2D(texture, texcoord);
	}
	
	//fragColor = vec4(texcoord.xy, 0.0, 1.0);
	fragColor = (ambient+diffuse+specularCoefficient*specular) * texcol;
	fragColor = vec4(fragColor.xyz, opacity);
	
	//fragColor.xy = gl_FragCoord.xy / 800;
	
	//fragColor = vec4(texcoord, 1, 1);
	//fragColor= vec4(position, 1);
	//fragColor = objectSpacePos;
	//fragColor = vec4(gl_TexCoord[0].st, 1,1);

}
