// specular.vert

#version 130              // delete this line if using GLSL 1.2
precision mediump float;  // delete this line if using GLSL 1.2

// uniform shader-parameters
uniform mat4 world;
uniform mat4 view;
uniform mat4 proj;
uniform vec3 camPos;
uniform vec4 clipPlanes[5];
uniform int clipPlaneCount;

// vertex-shader input variables
in vec4 vertex;
in vec4 color;
in vec3 normal;
in vec2 inTexCoord;


// vertex-shader output variables (passed to fragment-shader)
out vec4 frag_color;
out vec3 world_normal;
out vec4 world_position;
out vec2 texcoord;
out vec3 eye;
out vec4 objectSpacePos;

void main()
{
	objectSpacePos = vertex;

	// transform normal into world space

	vec4 normal4 = vec4(normal, 0.0f);
    world_normal = (world * normal4).xyz;
    
    // transform vertex to world-space
    world_position = world * vertex;
    
    // just pass color to fragment-shader
    frag_color = color;
	
	eye = normalize(camPos - world_position.xyz);
	
	texcoord = inTexCoord;
	
	for(int i = 0; i < clipPlaneCount; i = i+1){
		vec3 clip = clipPlanes[i].xyz;
		float d = dot(clip, world_position.xyz);
		d = d+clipPlanes[i].w;
		gl_ClipDistance[i] = d;
	}
	
	vec4 pos = proj * view * world * vertex;

    // transform vertex down the pipeline
    gl_Position = pos;
}
